
# Type: aggregate statistic




URI: [biolink:aggregate_statistic](https://w3id.org/biolink/vocab/aggregate_statistic)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children

 *  [has count](has_count.md)
 *  [has percentage](has_percentage.md)
 *  [has quotient](has_quotient.md)
 *  [has total](has_total.md)

## Used by

 * [NamedThing](NamedThing.md)
